# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2012 Thinkopen Solutions, Lda. All Rights Reserved
#    http://www.thinkopensolutions.com.
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv
from osv import fields
from tools.translate import _
from datetime import datetime

OVERALL_EVALUATION_SCORE = [
    ('1', '1 - Fraco'),
    ('2', '2 - Na Média'),
    ('3', '3 - Muito Bom'),
]

class hr_applicant(osv.osv):
    _name = "hr.applicant"
    _inherit = "hr.applicant"
    _description = "Applicant"
    
    def _compute_experience(self, cr, uid, ids, fields, args, context=None):
        res = [] 
        for line in self.browse(cr, uid, ids):
            if line.career_start_date:
                year, month, day = line.career_start_date.split('-')
                current_year = datetime.now().strftime('%Y')
                years_experience = int(current_year) - int(year)
                res.append((line.id, years_experience))
            else:
                res.append((line.id, 0))
        return dict(res)

    _columns = {
        'create_date': fields.date('Creation Date', readonly=True, select=True),
        'birthday': fields.date("Date of Birth"),
        'career_start_date': fields.date('Career Start Date'),
        'gender': fields.selection([('male', 'Male'),('female', 'Female')], 'Gender'),
        'marital': fields.selection([('single', 'Single'), ('married', 'Married'), ('widower', 'Widower'), ('divorced', 'Divorced')], 'Marital Status'),
        'city': fields.char('City', size=20),
        'country_id': fields.many2one('res.country', 'Nationality'),
        'priority': fields.selection(OVERALL_EVALUATION_SCORE, 'Appreciation'),
        'work_experience_ids': fields.one2many('hr.applicant.work_experience', 'applicant_id','Work Experiences'),
        'base_education_ids': fields.one2many('hr.applicant.base_education', 'applicant_id','Base Education'),
        'aditional_course_ids': fields.one2many('hr.applicant.aditional_course', 'applicant_id','Aditional Courses'),
        'experience_years': fields.function(_compute_experience, string='Exp.', type="integer", method=True, size=64),
        
    }
    
hr_applicant()

class hr_applicant_position(osv.osv):
    _name = "hr.applicant.position"
    _description = "Position"
    _columns = {
        'name': fields.text('Name'),
    }
    
hr_applicant_position()

class hr_applicant_work_experience(osv.osv):
    _name = "hr.applicant.work_experience"
    _description = "Work Experience"
    _columns = {
        'applicant_id': fields.many2one('hr.applicant','Applicant ID'),
        'start_date': fields.date("Start Date"),
        'end_date': fields.date("End Date"),
        'company_id': fields.many2one('res.partner', 'Company'),
        'client_id': fields.many2one('res.partner', 'Client'),
        'position_id': fields.many2one('hr.applicant.position', 'Position Name'),
        'role_description': fields.text('Role Description'),
        'technologies': fields.text('Technologies')
    }

hr_applicant_work_experience()

class hr_applicant_base_education(osv.osv):
    _name = "hr.applicant.base_education"
    _description = "Base Education"
    _columns = {
        'applicant_id': fields.many2one('hr.applicant','Applicant ID'),
        'start_date': fields.date("Start Date"),
        'end_date': fields.date("End Date"),
        'institution_id': fields.many2one('res.partner', 'Institution'),
        'course_id': fields.many2one('hr.applicant.course', 'Course Name'),
    }

hr_applicant_base_education()

class hr_applicant_course(osv.osv):
    _name = "hr.applicant.course"
    _description = "Course"
    _columns = {
        'name': fields.text('Name'),
    }
    
hr_applicant_course()

class hr_applicant_aditional_course(osv.osv):
    _name = "hr.applicant.aditional_course"
    _description = "Aditional Course"
    _columns = {
        'applicant_id': fields.many2one('hr.applicant','Applicant ID'),
        'start_date': fields.date("Start Date"),
        'end_date': fields.date("End Date"),
        'institution_id': fields.many2one('res.partner', 'Institution'),
        'course_id': fields.many2one('hr.applicant.course', 'Course Name'),
    }
    
hr_applicant_aditional_course()
